cumulusci.tasks.bulkdata package
================================

Subpackages
-----------

.. toctree::

    cumulusci.tasks.bulkdata.tests

Submodules
----------

cumulusci.tasks.bulkdata.base\_generate\_data\_task module
----------------------------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.base_generate_data_task
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.bulkdata.delete module
--------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.delete
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.bulkdata.extract module
---------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.extract
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.bulkdata.factory\_utils module
----------------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.factory_utils
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.bulkdata.generate module
----------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.generate
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.bulkdata.load module
------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.load
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.bulkdata.utils module
-------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.bulkdata
    :members:
    :undoc-members:
    :show-inheritance:
